#### Files Menu

Scan Folder:

This is the first selection in the Files menu of the main menu of the application. It is used to launch a folder selection navigation dialog with which you can select folders for the application to scan for image files. The image files found will be included in the list which is on the left side of the content area of the main application window. 'Scan Folder' has a submenu with two selections, 'Walk', and 'List'. If you select 'Walk', all of the folders that you select in the navigator will be scanned recursively down to the depth of the folder hierarchy and any image files contained in them will be included in the list. If you select 'List', then only the image files in the folder itself, but none of its sub-folders, will be included.

You may use the CTRL and SHIFT keys in combination with mouse clicks to select ranges or sets of folders to scan. With the CTRL key / mouse click combination, you can select multiple individual folders, and with the SHIFT key / mouse click combination you can select ranges. If you are unfamiliar with these standard list and tree view features, experiment a bit to learn how they work.

Click the [Cancel] button at the bottom of the file system navigator to cancel selection and exit the dialog. Click the [Select] button to perform the scan, exit the navigator, and list the image files found in the main application window. The full path of each file is shown. The [Up] button is useful if you have descended into sub-folders by double clicking folders and want to go back up in the folder hierarchy.

Select Text:

Use this selection to select or crop text from one or more of the image files in the list. Each image file in the list has a check box to its left. To select the file for text cropping, click on the check box to select it. Only those files with the check box clicked will be shown during the cropping operation. Selecting this menu item causes a series of dialogs to appear, each containing the image in each of the files checked. With the image displayed in the cropping dialog, drag the mouse from the top left corner of the text to crop to the bottom right. Releasing the mouse button starts the cropping operation, which might take a couple of seconds depending on how much text you selected.

The cropped text will be written to the console, so if you started the application using a console command then the text will be available there. It is also written to the database in the SQLite database file, TextExtraction.db, which, depending on your particular installation method, will be in the same folder as the pictureTextCrop.py source code file. Whichever directory this file is in when the application is started is its working directory, which will be where it initializes and stores its database. When you crop text from an image, a record is written to the CropLog table. The record will contain fields recording the a time-stamp showing when the extraction was done in a text sortable format, the full file path identifying the file on your storage media, the text extracted, and the coordinates of the rectangle you drew in the image defining the boundaries of the text extraction. This can be searched and otherwise used efficiently using SQL, and so serves as an export point for the payload produced by the application.

The cropping dialog for each file will remain displayed until you close it using the standard X button at its top right corner. You can continue to crop any number of pieces of text in it until it is closed. You can work in any order through the files you checked in the list to crop using the 'Select Text' feature in the Files menu.

Select All:

This is a toggle with which you can select and un-select all of the files in the list. Notice that it does not check all of the boxes to the right of the file paths, but rather highlights all of the files. This selection method only works with certain features, one of which is accessed with the button in the icon tool bar with the blue double-play arrows, '>>'. All files in the list which are highlighted will be displayed one at a time in the crop dialog when you select this feature. In addition to selecting all of the files in the list at once, you can select files in the list using the same CTRL- and SHIFT-plus-mouse-click operations that you can use in the file system navigator for selecting multiple folders. When you click on the '>>' button, the crop dialog will display for each of the highlighted files in turn. You can select one slice of text from each.

Exit:

This selection exits the application.